@@ -1,7 +1,6 @@
 #include <Rcpp.h>
-
-#include "XlsWorkSheet.h"
 #include "ColSpec.h"
+#include "XlsWorkSheet.h"
 #include <libxls/xls.h>
 using namespace Rcpp;
 
@@ -9,10 +8,11 @@ using namespace Rcpp;
 List read_xls_(std::string path, int sheet_i,
                IntegerVector limits, bool shim,
                RObject col_names, RObject col_types,
-               std::vector<std::string> na, bool trim_ws, int guess_max = 1000) {
+               std::vector<std::string> na, bool trim_ws,
+               int guess_max = 1000, bool progress = true) {
 
   // Construct worksheet ----------------------------------------------
-  XlsWorkSheet ws(path, sheet_i, limits, shim);
+  XlsWorkSheet ws(path, sheet_i, limits, shim, progress);
 
   // catches empty sheets and sheets where requested rectangle contains no data
   if (ws.nrow() == 0 && ws.ncol() == 0) {
